==> haskell-gtk2hs-buildtools-0.13.8.0-133-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gtk2hs-buildtools
version:              0.13.8.0
visibility:           public
id:                   gtk2hs-buildtools-0.13.8.0-KSlMNHlWKdV1NpzlIa1bgK
key:                  gtk2hs-buildtools-0.13.8.0-KSlMNHlWKdV1NpzlIa1bgK
license:              GPL-2.0-only
copyright:            (c) 2001-2010 The Gtk2Hs Team
maintainer:           gtk2hs-devel@lists.sourceforge.net
author:               Axel Simon, Duncan Coutts, Manuel Chakravaty
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:
    Tools to build the Gtk2Hs suite of User Interface libraries.

description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.

category:             Development
abi:                  72d18950f6a76329dc19667567a01ac8
exposed:              True
exposed-modules:      Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules:
    Paths_gtk2hs_buildtools BaseVersion Config Errors Binary DLists
    FastMutInt FileOps FNameOps Map Position Set UNames CIO State
    StateBase StateTrans Attributes Idents NameSpaces Lexers C CAST
    CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty CTokens
    CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader C2HSState
    Switches C2HSConfig Version

import-dirs:          /usr/lib/ghc-9.0.1/site-local/gtk2hs-buildtools-0.13.8.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/gtk2hs-buildtools-0.13.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk2hs-buildtools
hs-libraries:         HSgtk2hs-buildtools-0.13.8.0-KSlMNHlWKdV1NpzlIa1bgK
depends:
    Cabal-3.4.0.0 array-0.5.4.0 base-4.15.0.0 containers-0.6.4.1
    directory-1.3.6.1 filepath-1.4.2.1
    hashtables-1.2.4.2-G0dHq1iCSbf49cX2x1DF1w pretty-1.1.3.6
    process-1.6.11.0 random-1.2.1-3QO1nwXdNe61pywCRD6QRB

haddock-interfaces:
    /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock

haddock-html:         /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk2hs-buildtools-0.13.8.0-140-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gtk2hs-buildtools
version:              0.13.8.0
visibility:           public
id:                   gtk2hs-buildtools-0.13.8.0-8FyDwOVcM3h9XLtgehtFEA
key:                  gtk2hs-buildtools-0.13.8.0-8FyDwOVcM3h9XLtgehtFEA
license:              GPL-2.0-only
copyright:            (c) 2001-2010 The Gtk2Hs Team
maintainer:           gtk2hs-devel@lists.sourceforge.net
author:               Axel Simon, Duncan Coutts, Manuel Chakravaty
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:
    Tools to build the Gtk2Hs suite of User Interface libraries.

description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.

category:             Development
abi:                  dee60d5a61b0596baa74697773fbc66a
exposed:              True
exposed-modules:      Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules:
    Paths_gtk2hs_buildtools BaseVersion Config Errors Binary DLists
    FastMutInt FileOps FNameOps Map Position Set UNames CIO State
    StateBase StateTrans Attributes Idents NameSpaces Lexers C CAST
    CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty CTokens
    CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader C2HSState
    Switches C2HSConfig Version

import-dirs:          /usr/lib/ghc-9.0.2/site-local/gtk2hs-buildtools-0.13.8.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/gtk2hs-buildtools-0.13.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk2hs-buildtools
hs-libraries:         HSgtk2hs-buildtools-0.13.8.0-8FyDwOVcM3h9XLtgehtFEA
depends:
    Cabal-3.4.1.0 array-0.5.4.0 base-4.15.1.0 containers-0.6.4.1
    directory-1.3.6.2 filepath-1.4.2.1
    hashtables-1.2.4.2-9KMeCyykOKXEkp7adNS4vT pretty-1.1.3.6
    process-1.6.13.2 random-1.2.1-87zKbQkst0gDIGMfu6nhpe

haddock-interfaces:
    /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock

haddock-html:         /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
